@@ -79,6 +79,8 @@ c     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
      *    (pj.fm.p(4) - pj.mass)/pj.subcode .gt. 5.1) then
               !   avoid recursive call from cdpmjet
            call cdpmjet(pj, ia, iz, a, ntp)
+        elseif(ActiveMdl .eq. 'qgsjet2') then
+           call cQGSjet(pj, ia, iz, a, ntp)
         elseif(ActiveMdl .eq. 'gheisha' .and.
      *        pj.code .eq. kgnuc  .and. (pj.subcode .eq. 2 .or.
      *        pj.subcode .eq. 3) ) then
