@@ -217,7 +217,7 @@ c     ===================================================
      *  ( o(Np).wy ),  
      *  ( o(Np).wz ),  
      *  ( o(Np).zenith ) 
- 959    format(3i3,f12.3,2f16.6,4(1x,f12.8))
+ 959    format(3i3, g14.3,2f16.6,4(1x,f12.8))
       endif
 
 c     ===================================================
@@ -271,11 +271,14 @@ c         count sum Eg etc
       enddo
 
 c     ===================================================
-
-
       memorize =(ng .ge. NgMin .and. sumeg .ge. SumegMin) .or.
      *  ( nh .ge. NhMin .and. sumeh .ge. SumehMin)
 
+c/////
+      write(0,*) ' memo=', memorize,
+     *   ' ng=',ng, ' seg=',sumeg, ' nh=',nh,' seh=',sumeh
+c//////
+
 
 c     ===================================================
       if(memorize) then
