@@ -35,9 +35,10 @@ c	(->	------------------------------------
 	integer       InitRN       !1  Initial random number seed. 2 integers. If InitRN(1) $<$ 0, file dev  \# 14
                                    !    is  assumed to have  pairs of IR in each row, and they are read to
                                    !    initialize each event.  This feature is ignored when Job = 'flesh' or 
-                                   !    'newflesh'. The \# 14 file should be
-                                   ! opened by the user routine (chookBgRun). This is almost debug purpose.\newline
-                                   ! If InitRn(2)$<$0, timer and host name are used for the initialization.
+                                   !    'newflesh'. The \# 14 file should be opened by the user routine
+                                   !    (chookBgRun). This is almost debug purpose.\newline
+                                   !   If InitRn(2)$<$0, timer, hostname and process number are used for the 
+                                   !    initialization.
 	integer       EventNo      !2  cumulative event number counter.(excluding discarded ones due to cutoff).
 	integer       EventsInTheRun !2  Counter for event number in the run. Internal use.
                                      !          (excluding discarded ones due to cutoff).
@@ -72,6 +73,29 @@ c	(->	------------------------------------
                                    !   component, the use may 'call ccqUHooki(i, iv)' in the userHook rouitne,
                                    !   where iv is an integer varialbe to receive the data.
         character*100 AtmosFile    !2  path to the atmospheric data as in 'Cosmos/Data/Atmos/stdatmos2.d'
+
+        character*32  AtEnv        !2  If this is non blank, an environmental variable with that name is
+                                   !   assumed to exist and Cosmos tries to get the value of that env variable.
+                                   !   If the value is obtained, the \verb/@/ in \verb/@_/ or \verb/@./
+                                   !   expressing a part of a file name is replaced by that value. 
+                                   !   (default is blank and in that case the \verb/@/ is replaced by
+                                   !    the host name where  the job runs.)
+
+        character*32 SharpEnv      !2  If this is non blank, an environmental variable with that name is
+                                   !   assumed to exist and Cosmos tries to get the value of that env variable.
+                                   !   If the value is obtained, the \verb/#/ in \verb/#_/ or \verb/#./ 
+                                   !   expressing a  part of a file name is replaced by that value. 
+                                   !   (default is blank and in that case the \verb/#/ is replaced by
+                                   !    the process number of the run).
+
+        character*32 PercentEnv    !2  If this is non blank, an environmental variable with that name is
+                                   !   assumed to exist and Cosmos tries to get the value of that env variable.
+                                   !   If the value is obtained, the \verb/%/ in \verb/%_/ or \verb/%./ 
+                                   !   expressing a  part of a file name is replaced by that value. 
+                                   !   (default is blank and in that case the \verb/%/ is replaced by
+                                   !    the USER name).
+
+
 c	<-)	-------------------------------------
 	common /Zmanagerpc/
      *  BaseTime,  BaseErg, BasePower, Within, UserHookr(MAX_USERHOOKR),
@@ -83,4 +107,6 @@ c	<-)	-------------------------------------
        common /Zmanagerpc2/
      * UserHookc(MAX_USERHOOKC), PrimaryFile,
      * CutOffFile,  Job, ContFile, AtmosFile, GeomagFile,
-     * SkeletonFile, SeedFile, DpmFile, DeadLine
+     * SkeletonFile, SeedFile, DpmFile, DeadLine, SharpEnv,
+     * PercentEnv, AtEnv
+ 
