@@ -50,7 +50,11 @@ c            AS generation.
          endif
 c        ----------------------------
          if(icon .eq. 0) then
-            call cTracking
+c              see if heavy and ssp is needed; icon =1 --> SSP so skip tracking here
+            call cforceSSP(TrackBefMove, icon)
+            if(icon .eq. 0) then
+               call cTracking
+            endif
          else
             MoveStat = Dead
 #if DETAILED_TRACKING >=1
@@ -99,7 +103,7 @@ cc      integer icon
 #endif
 
       call cfixModel( TrackBefMove.p )      ! fix interaction model.
-      call cfixMedia            ! 
+      call cfixMag            !   Mag field
 c           sample interaction length.  The path may
 c           be truncated to a shorter one than really sampled.
 c           In that case, MoveStat == Truncated.
@@ -352,7 +356,7 @@ c         endif
       end
 #endif
 c-------------------------------------------------------
-      subroutine cfixMedia
+      subroutine cfixMag
       implicit none
 #include "Ztrack.h"
 #include "Ztrackv.h"
@@ -367,27 +371,6 @@ c-------------------------------------------------------
       integer icon
       real*8 u
 
-c       weight average  ! weight ratio: 75.53, 23.14, 1.28 %
-      TargetMassN = 14.7
-      TargetAtomicN = 7.36
-      TargetZ2 = 55.7  ! <Z^2>
-      
-      call rndc(u)
-c            volume ratio
-      if(u .lt. .78) then
-c          nitrogen
-         TargetNucleonNo = 14
-         TargetProtonNo = 7
-      elseif(u .lt. .99) then
-c             oxigen
-         TargetNucleonNo = 16
-         TargetProtonNo = 8
-      else
-c         argon
-         TargetNucleonNo = 40
-         TargetProtonNo = 18
-      endif
-
       if(HowGeomag .le. 2 .or. HowGeomag .eq. 31) then
 c             distant; change of B is < 1 % (for default
 c             MagChgDist =20 km; you can change it)
@@ -426,7 +409,7 @@ c                in m).  They are stored in a record /intinf/ IntInfArray
 c                given in Ztrackv.h;  
 c            In the routine,  cfixProc, 
 c                we take the minimum of values given in kg/m2, and
-c                convert it in real lenght (m).  In this process,
+c                convert it in real length (m).  In this process,
 c                path truncation may occur (if the particle is
 c                going upward, and there is very thin air there,
 c                then the given thickness may not be realized.
@@ -568,3 +551,61 @@ c////////////
          IntInfArray(ProcessNo).thickness  = thick
       endif
       end
+c      *************** for same model, we must use simple super position for heavy
+c      If so, current particle is decomposed into nucelons and put into stack
+c      and icon =1  is made. else icon = 0
+      subroutine  cforceSSP(atrack, icon)
+#include "Ztrack.h"
+#include "Zevhnp.h"
+#include "Zcode.h"
+#include "Zmass.h"
+
+      integer icon
+      record /track/atrack  ! input current projectile.
+
+      record /track/pj
+      integer i, j
+      real*8  p, po, pr
+
+      icon = 0
+      if(atrack.p.code .eq. kgnuc) then
+         call cfixModel(atrack)
+         if(ActiveMdl .eq. 'dpmjet3' .and. 
+     *      atrack.p.subcode .gt. 18) then
+            icon = 1
+         elseif( ActiveMdl .eq. 'incdpm3') then
+            icon = 1
+         endif
+      endif
+      if( icon  .eq. 1 ) then
+         pj = atrack
+         pj.p.fm.p(4) = atrack.p.fm.p(4)/atrack.p.subcode
+         pj.p.mass = masp
+         pj.p.code = knuc
+         pj.p.subcode = -1
+         pj.p.charge = 1
+
+         p = sqrt(pj.p.fm.p(4)**2 - masp**2)      
+         po = atrack.p.fm.p(1)**2 + atrack.p.fm.p(2)**2 +
+     *           atrack.p.fm.p(3)**2 
+         po = sqrt(po)
+         pr = p/po
+         do j = 1, 3
+            pj.p.fm.p(j) = atrack.p.fm.p(j)*pr
+         enddo
+         do i = 1, atrack.p.charge
+            call cpush(pj)
+         enddo
+
+         pj.p.mass = masn
+         p = sqrt(pj.p.fm.p(4)**2 - masn**2)      
+         pr = p/po
+         pj.p.charge = 0
+         do j = 1, 3
+            pj.p.fm.p(j) = atrack.p.fm.p(j)*pr
+         enddo
+         do i = 1, atrack.p.subcode - atrack.p.charge
+            call cpush(pj)
+         enddo
+      endif
+      end
